@@ -154,7 +154,9 @@ parse_user_id (const gchar *uid, gchar **name, gchar **email, gchar **comment)
                     tail = src + 1;
 		        }
 	            in_name = 0;
-	        }
+	        } else
+	            tail = src + 1;
+	            
 	        in_email = 1;
 	    } else if (*src == '(') {
 	        if (in_name) {
@@ -532,3 +534,16 @@ seahorse_pgp_uid_calc_markup (const gchar *name, const gchar *email,
 	 	          comment && comment[0] ? comment : "",
 	 	          comment && comment[0] ? "'" : "");
 }
+
+GQuark
+seahorse_pgp_uid_calc_id (GQuark key_id, guint index)
+{
+	gchar *str = NULL;
+	GQuark id = 0;
+	
+	str = g_strdup_printf ("%s:%u", g_quark_to_string (key_id), index + 1);
+	id = g_quark_from_string (str);
+	g_free (str);
+
+	return id;
+}
